It realizes the combination among the Qualitative Harmonic Analysis and the Multiply Factorial Analysis for the treatment of longitudinal qualitative variables.
combination(datos, vectorc, ilustra = NULL, ilustc=NULL, ilust.type=NULL,pesos=NULL)When in the AAC it is chosen for a recodification that indicates the proportion of time that an individual remains in a category, with regard to a specific period of time, there is obtained a table that can turn as a table of diffuse codification, that is to say, the individuals take different values of the same variable with different degrees of association; and this one can be analyzed across an extension of the analysis of multiple correspondences: the diffuse analysis of correspondences, proposed by Chevenet, Doledec and Chessel in 1994.
The analysis factorial multiple appears as a method factorial for the description of the same set of individuals across several groups of variables. In the longitudinal studies, the groups are formed according to the moment of the time in which the variables have been measured. It is obtained then, a table with combinations of transverse cuts in the time.
The function combination, considers the use of both methods to analyze longitudinal categorical data.
# data(ratingTV)
# AAC_FMA<-combination(datos=ratingTV$tab,vectorc=c(15,15,15,15,15,15),
# ilustra=ratingTV$ilus,ilustc=c(4))
#10
#AAC_FMA$separate.analyses
#AAC_FMA$eig
#AAC_FMA$group
#AAC_FMA$summary.quali
#AAC_FMA$partial.axes
Run the code above in your browser using DataLab