Learn R Programming

qha (version 0.0.8)

ratingTV: Rating TV in Colombia

Description

An application for the study of Colombian rating television data for a given day and the resulting typology of television viewers.

Usage

data(ratingTV)

Arguments

Format

Object of class list with: $tab a data.frame of 1306 rows and 90 columns; $ilus a data.frame of 1306 rows and 4 colums of sociodemographic variables; and a vector weights with the 1306 weights of the rows.

The Data were provided by professor Juan de la Rosa Ramos

References

Corrales, M.L., & Pardo, C.E. (2015). Analisis de datos longitudinales cualitativos con analisis de correspondencias y clasificacion. Comunicaciones en Estadistica, 8(1), 11-32. http://dx.doi.org/10.15332/s2027-3355.2015.0001.01