Rdocumentation
powered by
Learn R Programming
qha (version 0.0.8)
duration: Calculate of duration time
Description
It calculates the duration time for every individual in the category of the longitudinal variable
Usage
duration(datos, units = "auto")
Arguments
datos
a data frame containing ID, Start-Time,End-Time, Modality of the Longitudinal Variable
units
unis time:"secs", "mins", "hours", "days", "weeks", "months", "years"
Value
Details
It calculates the duration time to the table containing ID, START_TIME,END_TIME,MODALIDAD