It realizes the transformation of the table that contains the durations
in every modality of the longitudinal variable in the table that it groups for periods of time
Usage
durationtotableA(x,periodos)
Arguments
x
a data frame containing ID, Modality of the Longitudinal Variable, Duration
periodos
a vector containing the duration of each period time to do a groups
Value
Details
This function transforms the table that contains the durations passed by the individuals
in every modality of a longitudinal variable, in the table that groups these modalities in periods of time.
That is to say, in the table that contains the quantity of time
that an individual remains in a category of the longitudinal variable, in every period of time