ratingTV: Rating TV in Colombia
Description
An application for the study of Colombian rating television data for a given day and the resulting
typology of television viewers.
Format
Object of class list with: $tab a data.frame of 1306 rows and 90 columns; $ilus a data.frame of 1306 rows and 4 colums of sociodemographic variables; and a vector weights with the 1306 weights of the rows.Source
The Data were provided by professor Juan de la Rosa Ramos